@@ -2,10 +2,11 @@ import os
 import sys
 
 import logbook
-from config import *
 from logbook import StreamHandler
 from logbook.more import ColorizingStreamHandlerMixin
 
+from .config import *
+
 __all__ = ()
 logging_map = {
     "CRITICAL": logbook.CRITICAL,
